
:orphan:

.. _sphx_glr_sg_execution_times:


Computation times
=================
**08:47.984** total execution time for 39 files **from all galleries**:

.. container::

  .. raw:: html

    <style scoped>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/twitter-bootstrap/5.3.0/css/bootstrap.min.css" rel="stylesheet" />
    <link href="https://cdn.datatables.net/1.13.6/css/dataTables.bootstrap5.min.css" rel="stylesheet" />
    </style>
    <script src="https://code.jquery.com/jquery-3.7.0.js"></script>
    <script src="https://cdn.datatables.net/1.13.6/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/1.13.6/js/dataTables.bootstrap5.min.js"></script>
    <script type="text/javascript" class="init">
    $(document).ready( function () {
        $('table.sg-datatable').DataTable({order: [[1, 'desc']]});
    } );
    </script>

  .. list-table::
   :header-rows: 1
   :class: table table-striped sg-datatable

   * - Example
     - Time
     - Mem (MB)
   * - :ref:`sphx_glr_examples_00-band_structure_plot_2d_bands.py` (``..\..\examples\00-band_structure\plot_2d_bands.py``)
     - 02:44.356
     - 0.0
   * - :ref:`sphx_glr_examples_03-fermi2d_plot_rashba_spin_spliting.py` (``..\..\examples\03-fermi2d\plot_rashba_spin_spliting.py``)
     - 01:03.790
     - 0.0
   * - :ref:`sphx_glr_examples_04-fermi3d_plot_fermi3d_isovalue_gif.py` (``..\..\examples\04-fermi3d\plot_fermi3d_isovalue_gif.py``)
     - 00:30.366
     - 0.0
   * - :ref:`sphx_glr_examples_04-fermi3d_plot_fermi3d_isoslider.py` (``..\..\examples\04-fermi3d\plot_fermi3d_isoslider.py``)
     - 00:29.115
     - 0.0
   * - :ref:`sphx_glr_examples_00-band_structure_plot_autobands.py` (``..\..\examples\00-band_structure\plot_autobands.py``)
     - 00:23.127
     - 0.0
   * - :ref:`sphx_glr_examples_06-PyPoscar_plot_utils_pyposcar.py` (``..\..\examples\06-PyPoscar\plot_utils_pyposcar.py``)
     - 00:22.359
     - 0.0
   * - :ref:`sphx_glr_examples_00-band_structure_plot_ipr.py` (``..\..\examples\00-band_structure\plot_ipr.py``)
     - 00:21.526
     - 0.0
   * - :ref:`sphx_glr_examples_00-band_structure_plot_unfolding.py` (``..\..\examples\00-band_structure\plot_unfolding.py``)
     - 00:20.196
     - 0.0
   * - :ref:`sphx_glr_examples_01-dos_plot_noncolinear_dos_qe.py` (``..\..\examples\01-dos\plot_noncolinear_dos_qe.py``)
     - 00:17.196
     - 0.0
   * - :ref:`sphx_glr_examples_04-fermi3d_plot_fermi3d_cross_section.py` (``..\..\examples\04-fermi3d\plot_fermi3d_cross_section.py``)
     - 00:15.681
     - 0.0
   * - :ref:`sphx_glr_examples_03-fermi2d_plot_fermi2d_spin_texture.py` (``..\..\examples\03-fermi2d\plot_fermi2d_spin_texture.py``)
     - 00:15.049
     - 0.0
   * - :ref:`sphx_glr_examples_03-fermi2d_plot_fermi2d_configurations.py` (``..\..\examples\03-fermi2d\plot_fermi2d_configurations.py``)
     - 00:14.125
     - 0.0
   * - :ref:`sphx_glr_examples_04-fermi3d_plot_fermi3d_spin_texture.py` (``..\..\examples\04-fermi3d\plot_fermi3d_spin_texture.py``)
     - 00:10.006
     - 0.0
   * - :ref:`sphx_glr_examples_06-PyPoscar_plot_finding_defects_pyposcar.py` (``..\..\examples\06-PyPoscar\plot_finding_defects_pyposcar.py``)
     - 00:09.143
     - 0.0
   * - :ref:`sphx_glr_examples_06-PyPoscar_plot_subsitution_pyposcar.py` (``..\..\examples\06-PyPoscar\plot_subsitution_pyposcar.py``)
     - 00:08.542
     - 0.0
   * - :ref:`sphx_glr_examples_06-PyPoscar_plot_clusters_pyposcar.py` (``..\..\examples\06-PyPoscar\plot_clusters_pyposcar.py``)
     - 00:07.662
     - 0.0
   * - :ref:`sphx_glr_examples_04-fermi3d_plot_fermi3d_spin-polarized.py` (``..\..\examples\04-fermi3d\plot_fermi3d_spin-polarized.py``)
     - 00:07.379
     - 0.0
   * - :ref:`sphx_glr_examples_04-fermi3d_plot_fermi3d_plain.py` (``..\..\examples\04-fermi3d\plot_fermi3d_plain.py``)
     - 00:04.578
     - 0.0
   * - :ref:`sphx_glr_examples_04-fermi3d_plot_fermi3d_configurations.py` (``..\..\examples\04-fermi3d\plot_fermi3d_configurations.py``)
     - 00:04.564
     - 0.0
   * - :ref:`sphx_glr_examples_01-dos_plot_colinear_dos.py` (``..\..\examples\01-dos\plot_colinear_dos.py``)
     - 00:04.406
     - 0.0
   * - :ref:`sphx_glr_examples_01-dos_plot_noncolinear_dos_vasp.py` (``..\..\examples\01-dos\plot_noncolinear_dos_vasp.py``)
     - 00:04.373
     - 0.0
   * - :ref:`sphx_glr_examples_04-fermi3d_plot_de_hass_van_alphen.py` (``..\..\examples\04-fermi3d\plot_de_hass_van_alphen.py``)
     - 00:04.146
     - 0.0
   * - :ref:`sphx_glr_examples_01-dos_plot_spin_polarized_dos.py` (``..\..\examples\01-dos\plot_spin_polarized_dos.py``)
     - 00:03.161
     - 0.0
   * - :ref:`sphx_glr_examples_00-band_structure_plot_colinear.py` (``..\..\examples\00-band_structure\plot_colinear.py``)
     - 00:02.830
     - 0.0
   * - :ref:`sphx_glr_examples_00-band_structure_plot_bandsplot_configurations.py` (``..\..\examples\00-band_structure\plot_bandsplot_configurations.py``)
     - 00:02.433
     - 0.0
   * - :ref:`sphx_glr_examples_03-fermi2d_plot_fermi2d.py` (``..\..\examples\03-fermi2d\plot_fermi2d.py``)
     - 00:02.414
     - 0.0
   * - :ref:`sphx_glr_examples_00-band_structure_plot_noncolinear_vasp.py` (``..\..\examples\00-band_structure\plot_noncolinear_vasp.py``)
     - 00:02.320
     - 0.0
   * - :ref:`sphx_glr_examples_00-band_structure_plot_spin_polarized.py` (``..\..\examples\00-band_structure\plot_spin_polarized.py``)
     - 00:02.218
     - 0.0
   * - :ref:`sphx_glr_examples_05-other_plot_ebs.py` (``..\..\examples\05-other\plot_ebs.py``)
     - 00:02.069
     - 0.0
   * - :ref:`sphx_glr_examples_02-bands_dos_plot_bandsdosplot_configurations.py` (``..\..\examples\02-bands_dos\plot_bandsdosplot_configurations.py``)
     - 00:02.004
     - 0.0
   * - :ref:`sphx_glr_examples_00-band_structure_plot_noncolinear_qe.py` (``..\..\examples\00-band_structure\plot_noncolinear_qe.py``)
     - 00:01.505
     - 0.0
   * - :ref:`sphx_glr_examples_01-dos_plot_dosplot_configurations.py` (``..\..\examples\01-dos\plot_dosplot_configurations.py``)
     - 00:01.257
     - 0.0
   * - :ref:`sphx_glr_examples_00-band_structure_plot_compare_bands.py` (``..\..\examples\00-band_structure\plot_compare_bands.py``)
     - 00:01.161
     - 0.0
   * - :ref:`sphx_glr_examples_00-band_structure_plot_atomic_levels.py` (``..\..\examples\00-band_structure\plot_atomic_levels.py``)
     - 00:01.129
     - 0.0
   * - :ref:`sphx_glr_examples_06-PyPoscar_plot_rdf_cutoff_pyposcar.py` (``..\..\examples\06-PyPoscar\plot_rdf_cutoff_pyposcar.py``)
     - 00:00.531
     - 0.0
   * - :ref:`sphx_glr_examples_05-other_plot_kpath_generation.py` (``..\..\examples\05-other\plot_kpath_generation.py``)
     - 00:00.449
     - 0.0
   * - :ref:`sphx_glr_examples_05-other_plot_2dkmesh_generation.py` (``..\..\examples\05-other\plot_2dkmesh_generation.py``)
     - 00:00.380
     - 0.0
   * - :ref:`sphx_glr_examples_02-bands_dos_plot_bandsdosplot.py` (``..\..\examples\02-bands_dos\plot_bandsdosplot.py``)
     - 00:00.320
     - 0.0
   * - :ref:`sphx_glr_examples_05-other_plot_bandgap.py` (``..\..\examples\05-other\plot_bandgap.py``)
     - 00:00.119
     - 0.0
